append_edge_to_struct

Function append_edge_to_struct 

pub fn append_edge_to_struct(
    struct_builder: &mut StructBuilder,
    eid: Eid,
    type_name: &str,
    src_vid: u64,
    dst_vid: u64,
    query_ctx: &QueryContext,
)
Append a single edge to an edge struct builder.

Writes _eid, _type_name, _src, _dst, and properties fields, then appends the struct row. The query_ctx is used to look up edge properties from the L0 visibility chain.