append_node_to_struct

Function append_node_to_struct 

pub fn append_node_to_struct(
    struct_builder: &mut StructBuilder,
    vid: Vid,
    query_ctx: &QueryContext,
)
Append a single node to a node struct builder.

Writes _vid, _labels, and properties fields, then appends the struct row. The query_ctx is used to look up labels and properties from the L0 visibility chain.