pub fn get_function_spec(name: &str) -> Option<&'static FunctionPropertySpec>Expand description
Look up the property specification for a function by name (case-insensitive).
pub fn get_function_spec(name: &str) -> Option<&'static FunctionPropertySpec>Look up the property specification for a function by name (case-insensitive).