pub struct RewriteContext {
pub scope: HashMap<String, VariableInfo>,
pub stats: RewriteStats,
pub config: RewriteConfig,
}Expand description
Contextual information available during query rewriting
The context provides information about the current query environment, including variable scope, schema metadata, and configuration options.
Fields
scope: HashMap<String, VariableInfo>Variables currently in scope (from MATCH, WITH, etc.)
stats: RewriteStatsRewrite statistics (for observability)
config: RewriteConfigConfiguration flags
Implementations
Sourceimpl RewriteContext
impl RewriteContext
Sourcepub fn with_config(config: RewriteConfig) -> Self
pub fn with_config(config: RewriteConfig) -> Self
Create a new rewrite context with custom configuration
Sourcepub fn get_variable(&self, name: &str) -> Option<&VariableInfo>
pub fn get_variable(&self, name: &str) -> Option<&VariableInfo>
Get information about a variable in scope
Sourcepub fn add_variable(&mut self, name: String, info: VariableInfo)
pub fn add_variable(&mut self, name: String, info: VariableInfo)
Add a variable to the scope