pub fn is_duration_value(val: &Value) -> boolExpand description
Check if value is a duration (ISO 8601 string starting with āPā or temporal duration).
Note: Numbers are NOT automatically treated as durations. The duration() function can accept numbers as microseconds, but arbitrary numbers in arithmetic expressions should not be interpreted as durations.