pub fn build_path_struct_array(
nodes_array: ArrayRef,
rels_array: ArrayRef,
path_validity: Vec<bool>,
) -> Result<StructArray>Expand description
Build a path struct array from nodes and relationships list arrays.
Combines the nodes and relationships arrays into a single StructArray with
the standard path structure (nodes, relationships), applying the given
validity mask.