pub fn build_path_struct_field(path_var: &str) -> Field
Build path struct field for schema with given path variable name.
Creates a struct field with nodes and relationships lists.
nodes
relationships