pub fn analyze_pattern(
pattern: &Pattern,
input_schema: &Schema,
uni_schema: &Schema,
) -> Result<(String, Vec<TraversalStep>)>Expand description
Analyze a pattern to extract the anchor column and traversal steps.
The anchor is the first node in the pattern whose variable has {var}._vid
in the input schema. The remaining nodes/edges become traversal steps.