pub struct Executor { /* private fields */ }Implementations
Sourceimpl Executor
impl Executor
pub fn new(storage: Arc<StorageManager>) -> Self
pub fn new_with_writer( storage: Arc<StorageManager>, writer: Arc<RwLock<Writer>>, ) -> Self
Sourcepub fn set_procedure_registry(&mut self, registry: Arc<ProcedureRegistry>)
pub fn set_procedure_registry(&mut self, registry: Arc<ProcedureRegistry>)
Sets the external procedure registry for user-defined procedures.
pub fn set_xervo_runtime(&mut self, runtime: Option<Arc<ModelRuntime>>)
Sourcepub fn set_file_sandbox(&mut self, sandbox: FileSandboxConfig)
pub fn set_file_sandbox(&mut self, sandbox: FileSandboxConfig)
Set the file sandbox configuration for BACKUP/COPY/EXPORT commands. MUST be called with sandboxed config in server mode.
pub fn set_config(&mut self, config: UniConfig)
pub fn set_writer(&mut self, writer: Arc<RwLock<Writer>>)
pub fn set_use_transaction(&mut self, use_transaction: bool)
Sourceimpl Executor
impl Executor
Sourcepub async fn profile(
&self,
plan: LogicalPlan,
params: &HashMap<String, Value>,
) -> Result<(Vec<HashMap<String, Value>>, ProfileOutput)>
pub async fn profile( &self, plan: LogicalPlan, params: &HashMap<String, Value>, ) -> Result<(Vec<HashMap<String, Value>>, ProfileOutput)>
Profiles query execution and returns results with timing statistics.
Uses the DataFusion-based executor for query execution. Granular operator profiling will be added in a future release.
Sourceimpl Executor
impl Executor
Sourcepub async fn create_datafusion_planner(
&self,
prop_manager: &PropertyManager,
params: &HashMap<String, Value>,
) -> Result<(Arc<SyncRwLock<SessionContext>>, HybridPhysicalPlanner, Arc<PropertyManager>)>
pub async fn create_datafusion_planner( &self, prop_manager: &PropertyManager, params: &HashMap<String, Value>, ) -> Result<(Arc<SyncRwLock<SessionContext>>, HybridPhysicalPlanner, Arc<PropertyManager>)>
Create L0 context, session, and planner for DataFusion execution.
This is the shared setup for execute_datafusion and execute_merge_read_plan.
Returns (session_ctx, planner, prop_manager_arc).
Sourcepub fn collect_batches(
session_ctx: &Arc<SyncRwLock<SessionContext>>,
execution_plan: Arc<dyn ExecutionPlan>,
) -> BoxFuture<'_, Result<Vec<RecordBatch>>>
pub fn collect_batches( session_ctx: &Arc<SyncRwLock<SessionContext>>, execution_plan: Arc<dyn ExecutionPlan>, ) -> BoxFuture<'_, Result<Vec<RecordBatch>>>
Execute a DataFusion physical plan and collect all result batches.
Sourcepub async fn execute_datafusion(
&self,
plan: LogicalPlan,
prop_manager: &PropertyManager,
params: &HashMap<String, Value>,
) -> Result<Vec<RecordBatch>>
pub async fn execute_datafusion( &self, plan: LogicalPlan, prop_manager: &PropertyManager, params: &HashMap<String, Value>, ) -> Result<Vec<RecordBatch>>
Executes a query using the DataFusion-based engine.
Uses HybridPhysicalPlanner which produces DataFusion ExecutionPlan
trees with custom graph operators for graph-specific operations.
pub fn execute<'a>( &'a self, plan: LogicalPlan, prop_manager: &'a PropertyManager, params: &'a HashMap<String, Value>, ) -> BoxFuture<'a, Result<Vec<HashMap<String, Value>>>>
Sourcepub fn execute_stream(
self,
plan: LogicalPlan,
prop_manager: Arc<PropertyManager>,
params: HashMap<String, Value>,
) -> BoxStream<'static, Result<Vec<HashMap<String, Value>>>>
pub fn execute_stream( self, plan: LogicalPlan, prop_manager: Arc<PropertyManager>, params: HashMap<String, Value>, ) -> BoxStream<'static, Result<Vec<HashMap<String, Value>>>>
Executes a query as a stream of result batches.
Routes DDL/Admin through the fallback executor and everything else through DataFusion.