pub struct QueryPlanner { /* private fields */ }Implementations
Sourceimpl QueryPlanner
impl QueryPlanner
pub fn new(schema: Arc<Schema>) -> Self
Sourcepub fn with_params(self, params: HashMap<String, Value>) -> Self
pub fn with_params(self, params: HashMap<String, Value>) -> Self
Set query parameters for resolving $param references in SKIP/LIMIT.
pub fn plan(&self, query: Query) -> Result<LogicalPlan>
pub fn plan_with_scope( &self, query: Query, vars: Vec<String>, ) -> Result<LogicalPlan>
Sourcepub fn plan_pattern(
&self,
pattern: &Pattern,
initial_vars: &[VariableInfo],
) -> Result<LogicalPlan>
pub fn plan_pattern( &self, pattern: &Pattern, initial_vars: &[VariableInfo], ) -> Result<LogicalPlan>
Plan a MATCH pattern into a LogicalPlan (Scan → Traverse chains).
This is a public entry point for the Locy plan builder to reuse the existing pattern-planning logic for clause bodies.
pub fn properties_to_expr( &self, variable: &str, properties: &Option<Expr>, ) -> Option<Expr>
Sourcepub fn node_filter_expr(
&self,
variable: &str,
labels: &[String],
properties: &Option<Expr>,
) -> Option<Expr>
pub fn node_filter_expr( &self, variable: &str, labels: &[String], properties: &Option<Expr>, ) -> Option<Expr>
Build a filter expression from node properties and labels.
This is used for TraverseMainByType where we need to filter target nodes by both labels and properties. Label checks use hasLabel(variable, ‘label’).
Sourceimpl QueryPlanner
impl QueryPlanner
pub fn explain_plan(&self, ast: Query) -> Result<ExplainOutput>
pub fn explain_logical_plan(&self, plan: &LogicalPlan) -> Result<ExplainOutput>